@@ -192,7 +192,16 @@ XS(XS_builtin_func1_scalar)
             break;
 
         case OP_STRINGIFY:
-            Perl_pp_stringify(aTHX);
+            {
+                /* we could only call pp_stringify if we're sure there is a TARG
+                   and if the XSUB is called from call_sv() or goto it may not
+                   have one.
+                */
+                dXSTARG;
+                sv_copypv(TARG, *PL_stack_sp);
+                SvSETMAGIC(TARG);
+                rpp_replace_1_1_NN(TARG);
+            }
             break;
 
         default:
@@ -212,11 +221,10 @@ XS(XS_builtin_trim)
         croak_xs_usage(cv, "arg");
     }
 
-    dTARGET;
+    dXSTARG;
     SV *source = TOPs;
     STRLEN len;
     const U8 *start;
-    SV *dest;
 
     SvGETMAGIC(source);
 
@@ -264,33 +272,14 @@ XS(XS_builtin_trim)
         }
     }
 
-    dest = TARG;
+    sv_setpvn(TARG, (const char *)start, len);
 
-    if (SvPOK(dest) && (dest == source)) {
-        sv_chop(dest, (const char *)start);
-        SvCUR_set(dest, len);
-    }
-    else {
-        SvUPGRADE(dest, SVt_PV);
-        SvGROW(dest, len + 1);
+    if (DO_UTF8(source))
+        SvUTF8_on(TARG);
+    else
+        SvUTF8_off(TARG);
 
-        Copy(start, SvPVX(dest), len, U8);
-        SvPVX(dest)[len] = '\0';
-        SvPOK_on(dest);
-        SvCUR_set(dest, len);
-
-        if (DO_UTF8(source))
-            SvUTF8_on(dest);
-        else
-            SvUTF8_off(dest);
-
-        if (SvTAINTED(source))
-            SvTAINT(dest);
-    }
-
-    SvSETMAGIC(dest);
-
-    SETs(dest);
+    SETTARG;
 
     XSRETURN(1);
 }
@@ -467,13 +456,27 @@ static OP *ck_builtin_func1(pTHX_ OP *entersubop, GV *namegv, SV *ckobj)
         return newLISTOPn(opcode, wantflags,
             argop,
             NULL);
-    else
-        return newUNOP(opcode, wantflags, argop);
+    else {
+        OP * const op = newUNOP(opcode, wantflags, argop);
+
+        /* since these pp funcs can be called from XS, and XS may be called
+           without a normal ENTERSUB, we need to indicate to them that a targ
+           has been allocated.
+        */
+        if (op->op_targ)
+            op->op_private |= OPpENTERSUB_HASTARG;
+
+        return op;
+    }
 }
 
-XS(XS_builtin_indexed)
+/* This does not use the XS() macro so that op.c can see its prototype */
+void
+Perl_XS_builtin_indexed(pTHX_ CV *cv)
 {
     dXSARGS;
+    PERL_ARGS_ASSERT_XS_BUILTIN_INDEXED;
+    PERL_UNUSED_VAR(cv);
 
     switch(GIMME_V) {
         case G_VOID:
@@ -522,6 +525,56 @@ XS(XS_builtin_load_module)
     XSRETURN(1);
 }
 
+/* These pp_ funcs all need to use dXSTARG */
+
+PP(pp_refaddr)
+{
+    dXSTARG;
+    SV *arg = *PL_stack_sp;
+
+    SvGETMAGIC(arg);
+
+    if(SvROK(arg))
+        sv_setuv_mg(TARG, PTR2UV(SvRV(arg)));
+    else
+        sv_setsv(TARG, &PL_sv_undef);
+
+    rpp_replace_1_1_NN(TARG);
+    return NORMAL;
+}
+
+PP(pp_reftype)
+{
+    dXSTARG;
+    SV *arg = *PL_stack_sp;
+
+    SvGETMAGIC(arg);
+
+    if(SvROK(arg))
+        sv_setpv_mg(TARG, sv_reftype(SvRV(arg), FALSE));
+    else
+        sv_setsv(TARG, &PL_sv_undef);
+
+    rpp_replace_1_1_NN(TARG);
+    return NORMAL;
+}
+
+PP(pp_ceil)
+{
+    dXSTARG;
+    TARGn(Perl_ceil(SvNVx(*PL_stack_sp)), 1);
+    rpp_replace_1_1_NN(TARG);
+    return NORMAL;
+}
+
+PP(pp_floor)
+{
+    dXSTARG;
+    TARGn(Perl_floor(SvNVx(*PL_stack_sp)), 1);
+    rpp_replace_1_1_NN(TARG);
+    return NORMAL;
+}
+
 static OP *ck_builtin_funcN(pTHX_ OP *entersubop, GV *namegv, SV *ckobj)
 {
     const struct BuiltinFuncDescriptor *builtin = NUM2PTR(const struct BuiltinFuncDescriptor *, SvUV(ckobj));
@@ -569,7 +622,7 @@ static const struct BuiltinFuncDescriptor builtins[] = {
     { "load_module", NO_BUNDLE, &XS_builtin_load_module, &ck_builtin_func1, 0, true },
 
     /* list functions */
-    { "indexed",          SHORTVER(5,39), &XS_builtin_indexed,          &ck_builtin_funcN, 0, false },
+    { "indexed",          SHORTVER(5,39), &Perl_XS_builtin_indexed,     &ck_builtin_funcN, 0, false },
     { "export_lexically",      NO_BUNDLE, &XS_builtin_export_lexically, NULL,              0, true },
 
     { NULL, 0, NULL, NULL, 0, false }
