@@ -1,15 +1,13 @@
-
-require 5;
 use 5.008;
 ## Anything before 5.8.0 is GIMPY!
 ## This module is to be use()'d only by Pod::Simple::Transcode
 
 package Pod::Simple::TranscodeSmart;
 use strict;
+use warnings;
 use Pod::Simple;
-require Encode;
-use vars qw($VERSION );
-$VERSION = '3.40';
+use Encode;
+our $VERSION = '3.45';
 
 sub is_dumb  {0}
 sub is_smart {1}
