@@ -2,7 +2,7 @@ package Test2::API::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.302199';
+our $VERSION = '1.302204';
 
 
 use Carp qw/confess croak/;
@@ -25,7 +25,7 @@ my %LOADED = (
 use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
 use Test2::Util::HashBase qw{
     stack hub trace _on_release _depth _is_canon _is_spawn _aborted
-    errno eval_error child_error thrown
+    errno eval_error child_error thrown _failed _start_fail_count
 };
 
 # Private, not package vars
@@ -42,6 +42,8 @@ sub init {
     confess "The 'hub' attribute is required"
         unless $self->{+HUB};
 
+    $self->{+_START_FAIL_COUNT} = $self->{+HUB}->{failed} || 0;
+
     $self->{+_DEPTH} = 0 unless defined $self->{+_DEPTH};
 
     $self->{+ERRNO}       = $! unless exists $self->{+ERRNO};
@@ -64,6 +66,8 @@ sub DESTROY {
     my $hub = $self->{+HUB};
     my $hid = $hub->{hid};
 
+    $self->{+_FAILED} = ($hub->{failed} || 0) - $self->{+_START_FAIL_COUNT};
+
     # Do not show the warning if it looks like an exception has been thrown, or
     # if the context is not local to this process or thread.
     {
@@ -111,6 +115,12 @@ Cleaning up the CONTEXT stack...
         $_->($self) for reverse @$hcbk;
     }
     $_->($self) for reverse @$ON_RELEASE;
+
+    if (my @diags = Test2::API::test2_clear_pending_diags()) {
+        if ($self->{+_FAILED} || ${$self->{+_ABORTED}}) {
+            $self->diag($_) for @diags;
+        }
+    }
 }
 
 # release exists to implement behaviors like die-on-fail. In die-on-fail you
@@ -131,6 +141,8 @@ sub release {
     my $hub = $self->{+HUB};
     my $hid = $hub->{hid};
 
+    $self->{+_FAILED} = ($hub->{failed} || 0) - $self->{+_START_FAIL_COUNT};
+
     croak "context thinks it is canon, but it is not"
         unless $CONTEXTS->{$hid} && $CONTEXTS->{$hid} == $self;
 
@@ -146,6 +158,12 @@ sub release {
     }
     $_->($self) for reverse @$ON_RELEASE;
 
+    if (my @diags = Test2::API::test2_clear_pending_diags()) {
+        if ($self->{+_FAILED} || ${$self->{+_ABORTED}}) {
+            $self->diag($_) for @diags;
+        }
+    }
+
     # Do this last so that nothing else changes them.
     # If one of the hooks dies then these do not get restored, this is
     # intentional
@@ -1008,7 +1026,7 @@ L<https://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2020 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
