@@ -1,4 +1,4 @@
-package Opcode 1.61;
+package Opcode 1.67;
 
 use strict;
 
@@ -332,10 +332,12 @@ invert_opset function.
     list lslice splice push pop shift unshift reverse
 
     cond_expr flip flop andassign orassign dorassign and or dor xor
+    helemexistsor
 
     warn die lineseq nextstate scope enter leave
 
     rv2cv anoncode prototype coreargs avhvswitch anonconst
+    emptyavhv
 
     entersub leavesub leavesublv return method method_named
     method_super method_redir method_redir_super
@@ -349,6 +351,8 @@ invert_opset function.
     leaveeval -- needed for Safe to operate, is safe
 		 without entereval
 
+    methstart initfield
+
 =item :base_mem
 
 These memory related ops are not included in :base_core because they
@@ -373,6 +377,7 @@ used to implement a resource attack (e.g., consume all available CPU time).
 
     grepstart grepwhile
     mapstart mapwhile
+    anystart allstart anywhile
     enteriter iter
     enterloop leaveloop unstack
     last next redo
@@ -430,11 +435,6 @@ These are a hotchpotch of opcodes still waiting to be considered
     entertry leavetry -- can be used to 'hide' fatal errors
     entertrycatch poptry catch leavetrycatch -- similar
 
-    entergiven leavegiven
-    enterwhen leavewhen
-    break continue
-    smartmatch
-
     pushdefer
 
     custom -- where should this go
@@ -563,7 +563,7 @@ This tag holds opcodes related to loading modules and getting information
 about calling environment and args.
 
     require dofile 
-    caller runcv
+    caller runcv classname
 
 =item :still_to_be_decided
 
