@@ -23,6 +23,24 @@ struct gp {
     HEK *	gp_file_hek;	/* file first declared in (for -w) */
 };
 
+/*
+=for apidoc_section $GV
+
+=for apidoc      Am|GV *|GvREFCNT_inc|GV *gv
+=for apidoc_item   |GV *|GvREFCNT_inc_simple|GV *gv
+=for apidoc_item   |GV *|GvREFCNT_inc_simple_NN|GV *gv
+
+These all increment the reference count of the given SV, which must be a GV.
+They are useful when assigning the result into a typed pointer as they avoid
+the need to cast the result to the appropriate type.
+
+=cut
+*/
+
+#define GvREFCNT_inc(gv)            ((GV *)SvREFCNT_inc((SV *)gv))
+#define GvREFCNT_inc_simple(gv)     ((GV *)SvREFCNT_inc_simple((SV *)gv))
+#define GvREFCNT_inc_simple_NN(gv)  ((GV *)SvREFCNT_inc_simple_NN((SV *)gv))
+
 #define GvXPVGV(gv)	((XPVGV*)SvANY(gv))
 
 
@@ -279,10 +297,19 @@ Return the CV from the GV.
 /* gv_fetchfile_flags() */
 #define GVF_NOADD       0x01    /* don't add the glob if it doesn't exist */
 
-#define gv_fullname3(sv,gv,prefix) gv_fullname4(sv,gv,prefix,TRUE)
-#define gv_efullname3(sv,gv,prefix) gv_efullname4(sv,gv,prefix,TRUE)
-#define gv_fetchmethod(stash, name) gv_fetchmethod_autoload(stash, name, TRUE)
+#define Perl_gv_fullname3(mTHX, sv,gv,prefix)                           \
+        Perl_gv_fullname4(aTHX_ sv,gv,prefix,TRUE)
+#define Perl_gv_efullname3(mTHX, sv, gv, prefix)                        \
+        Perl_gv_efullname4(aTHX_ sv,gv,prefix,TRUE)
+#define Perl_gv_fetchmethod(mTHX, stash, name)                          \
+        Perl_gv_fetchmethod_autoload(aTHX_ stash, name, TRUE)
+
+/*
+=for apidoc_defn Am|GV *|gv_fetchsv_nomg|SV *name|I32 flags|const svtype sv_type
+=cut
+*/
 #define gv_fetchsv_nomg(n,f,t) gv_fetchsv(n,(f)|GV_NO_SVGMAGIC,t)
+
 #define gv_init(gv,stash,name,len,multi) \
         gv_init_pvn(gv,stash,name,len,GV_ADDMULTI*cBOOL(multi))
 #define gv_fetchmeth(stash,name,len,level) gv_fetchmeth_pvn(stash, name, len, level, 0)
@@ -290,7 +317,10 @@ Return the CV from the GV.
 #define gv_fetchmethod_flags(stash,name,flags) gv_fetchmethod_pv_flags(stash, name, flags)
 
 /*
-=for apidoc_defn ARdp|GV *|gv_autoload4|NULLOK HV *stash|NN const char *name|STRLEN len|I32 method
+=for apidoc_defn ARmd|GV *|gv_autoload4|NULLOK HV *stash                    \
+                                       |NN const char *name                 \
+                                       |STRLEN len                          \
+                                       |I32 method
 =cut
 
 */
@@ -316,10 +346,10 @@ Make sure there is a slot of the given type (AV, HV, IO, SV) in the GV C<gv>.
 =cut
 */
 
-#define gv_AVadd(gv) gv_add_by_type((gv), SVt_PVAV)
-#define gv_HVadd(gv) gv_add_by_type((gv), SVt_PVHV)
-#define gv_IOadd(gv) gv_add_by_type((gv), SVt_PVIO)
-#define gv_SVadd(gv) gv_add_by_type((gv), SVt_NULL)
+#define Perl_gv_AVadd(mTHX, gv) Perl_gv_add_by_type(aTHX_ (gv), SVt_PVAV)
+#define Perl_gv_HVadd(mTHX, gv) Perl_gv_add_by_type(aTHX_ (gv), SVt_PVHV)
+#define Perl_gv_IOadd(mTHX, gv) Perl_gv_add_by_type(aTHX_ (gv), SVt_PVIO)
+#define Perl_gv_SVadd(mTHX, gv) Perl_gv_add_by_type(aTHX_ (gv), SVt_NULL)
 
 /*
  * ex: set ts=8 sts=4 sw=4 et:
