@@ -118,11 +118,11 @@ value for the OP, but some use it for other purposes.
 
 #define PUSHMARK(p) \
     STMT_START {                                                      \
-        I32 * mark_stack_entry;                                       \
+        Stack_off_t * mark_stack_entry;                               \
         if (UNLIKELY((mark_stack_entry = ++PL_markstack_ptr)          \
                                            == PL_markstack_max))      \
             mark_stack_entry = markstack_grow();                      \
-        *mark_stack_entry  = (I32)((p) - PL_stack_base);              \
+        *mark_stack_entry  = (Stack_off_t)((p) - PL_stack_base);      \
         DEBUG_s(DEBUG_v(PerlIO_printf(Perl_debug_log,                 \
                 "MARK push %p %" IVdf "\n",                           \
                 PL_markstack_ptr, (IV)*mark_stack_entry)));           \
@@ -142,7 +142,7 @@ value for the OP, but some use it for other purposes.
 #define dSP		SV **sp = PL_stack_sp
 #define djSP		dSP
 #define dMARK		SV **mark = PL_stack_base + POPMARK
-#define dORIGMARK	const I32 origmark = (I32)(mark - PL_stack_base)
+#define dORIGMARK	const SSize_t origmark = (SSize_t)(mark - PL_stack_base)
 #define ORIGMARK	(PL_stack_base + origmark)
 
 #define SPAGAIN		sp = PL_stack_sp
@@ -177,12 +177,11 @@ See C<L</PUSHMARK>> and L<perlcall> for other uses.
 =for apidoc Amn|SV*|POPs
 Pops an SV off the stack.
 
-=for apidoc Amn|char*|POPp
-Pops a string off the stack.
+=for apidoc      Amn|char*|POPp
+=for apidoc_item    |char*|POPpx
 
-=for apidoc Amn|char*|POPpx
-Pops a string off the stack.  Identical to POPp.  There are two names for
-historical reasons.
+These each pop a string off the stack.
+There are two names for historical reasons.
 
 =for apidoc Amn|char*|POPpbytex
 Pops a string off the stack which must consist of bytes i.e. characters < 256.
@@ -387,7 +386,7 @@ Does not use C<TARG>.  See also C<L</XPUSHu>>, C<L</mPUSHu>> and C<L</PUSHu>>.
 /* EXTEND_HWM_SET: note the high-water-mark to which the stack has been
  * requested to be extended (which is likely to be less than PL_stack_max)
  */
-#if defined DEBUGGING && !defined DEBUGGING_RE_ONLY
+#ifdef PERL_USE_HWM
 #  define EXTEND_HWM_SET(p, n)                                     \
         STMT_START {                                               \
             SSize_t extend_hwm_set_ix = (p) - PL_stack_base + (n); \
@@ -681,51 +680,6 @@ Does not use C<TARG>.  See also C<L</XPUSHu>>, C<L</mPUSHu>> and C<L</PUSHu>>.
 /* No longer used in core. Use AMG_CALLunary instead */
 #define AMG_CALLun(sv,meth) AMG_CALLunary(sv, CAT2(meth,_amg))
 
-#define tryAMAGICunTARGETlist(meth, jump)			\
-    STMT_START {						\
-        dSP;							\
-        SV *tmpsv;						\
-        SV *arg= *sp;						\
-        U8 gimme = GIMME_V;                                    \
-        if (UNLIKELY(SvAMAGIC(arg) &&				\
-            (tmpsv = amagic_call(arg, &PL_sv_undef, meth,	\
-                                 AMGf_want_list | AMGf_noright	\
-                                |AMGf_unary))))                 \
-        {                                       		\
-            SPAGAIN;						\
-            if (gimme == G_VOID) {                              \
-                NOOP;                                           \
-            }                                                   \
-            else if (gimme == G_LIST) {				\
-                SSize_t i;                                      \
-                SSize_t len;                                    \
-                assert(SvTYPE(tmpsv) == SVt_PVAV);              \
-                len = av_count((AV *)tmpsv);                    \
-                (void)POPs; /* get rid of the arg */            \
-                EXTEND(sp, len);                                \
-                for (i = 0; i < len; ++i)                       \
-                    PUSHs(av_shift((AV *)tmpsv));               \
-            }                                                   \
-            else { /* AMGf_want_scalar */                       \
-                dATARGET; /* just use the arg's location */     \
-                sv_setsv(TARG, tmpsv);                          \
-                if (PL_op->op_flags & OPf_STACKED)              \
-                    sp--;                                       \
-                SETTARG;                                        \
-            }                                                   \
-            PUTBACK;						\
-            if (jump) {						\
-                OP *jump_o = NORMAL->op_next;                   \
-                while (jump_o->op_type == OP_NULL)		\
-                    jump_o = jump_o->op_next;			\
-                assert(jump_o->op_type == OP_ENTERSUB);		\
-                (void)POPMARK;                                        \
-                return jump_o->op_next;				\
-            }							\
-            return NORMAL;					\
-        }							\
-    } STMT_END
-
 /* This is no longer used anywhere in the core. You might wish to consider
    calling amagic_deref_call() directly, as it has a cleaner interface.  */
 #define tryAMAGICunDEREF(meth)						\
