@@ -16,7 +16,7 @@
 #
 # This script is normally invoked from regen.pl.
 
-$VERSION = '1.68';
+$VERSION = '1.72';
 
 BEGIN {
     require './regen/regen_lib.pl';
@@ -80,8 +80,6 @@ our $WARNING_TREE = {
                                 'deprecated::dot_in_inc'               => [ 5.025011, DEFAULT_ON],
                                 'deprecated::version_downgrade'        => [ 5.035009, DEFAULT_ON],
                                 'deprecated::delimiter_will_be_paired' => [ 5.035010, DEFAULT_ON],
-                                'deprecated::apostrophe_as_package_separator'
-                                                                       => [ 5.037009, DEFAULT_ON],
                                 'deprecated::smartmatch'               => [ 5.037010, DEFAULT_ON],
                                 'deprecated::missing_import_called_with_args'   
                                                                        => [ 5.039002, DEFAULT_ON],
@@ -160,6 +158,10 @@ our $WARNING_TREE = {
                                     [ 5.035, DEFAULT_ON],
                                 'experimental::class' =>
                                     [ 5.037, DEFAULT_ON ],
+                                'experimental::any' =>
+                                    [ 5.041, DEFAULT_ON ],
+                                'experimental::all' =>
+                                    [ 5.041, DEFAULT_ON ],
                         }],
 
         'missing'       => [ 5.021, DEFAULT_OFF],
@@ -194,6 +196,8 @@ my %NO_BIT_FOR = map { ( uc $_ => 1, $_ => 1 ) } qw(
   experimental::script_run
   experimental::isa
   experimental::smartmatch
+  experimental::const_attr
+  experimental::for_list
 );
 
 ###########################################################################
